.. AUTHORS.rst
.. ===========
..
.. Copying
.. -------
..
.. Copyright (c) 2020 none authors and contributors.
..
.. This file is part of the *none* project.
..
.. None is a free software project. You can redistribute it and/or
.. modify it following the terms of the MIT License.
..
.. This software project is distributed *as is*, WITHOUT WARRANTY OF ANY
.. KIND; including but not limited to the WARRANTIES OF MERCHANTABILITY,
.. FITNESS FOR A PARTICULAR PURPOSE and NONINFRINGEMENT.
..
.. You should have received a copy of the MIT License along with
.. *none*. If not, see <http://opensource.org/licenses/MIT>.

Authors of the *none* project
=============================

Below listed are the official copyright holders for the *none* project.

If submission is made on behalf of Contributor's company, the company should be
listed here. Contributor can however be listed in the ``CONTRIBUTORS.rst`` file
and therefore agree with contribution agreement.

Name should be kept alphabetically sorted and added in the following form::

    - Full Name or Organization <email address>


List of copyright holders
-------------------------

- Jimmy Thrasibule <dev@jimmy.lt>
